==> bastard-0.16.tgz: bastard_src-0.16/include/api/api_func.h <==
/*  B A S T A R D    A P I  :  */
/*  */

#include <bdb.h>  /* main DB structure definitions */

/* Public Parts */
/*  func_new: 
 *    Return Value:   
 *     Arguments:       */
int func_new( long rva, char * name, int size, int flags );
/*  func_get_name: 
 *    Return Value:   
 *     Arguments:       */
int func_get_name( long rva, char *buf );
/*  func_get_start: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
int func_get_start( long rva );
/*  func_get_end: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
int func_get_end( long rva );
/*  func_get_by_name: 
 *    Return Value:   
 *     Arguments:       */
int func_get_by_name( char *name );
/*  func_set_name: 
 *    Return Value:   
 *     Arguments:       */
int func_set_name( long rva, char *name );
/*  func_set_size: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
int func_set_size( long rva, int size );
int func_gen_args( struct function *f );
int func_gen_effect( struct function *f );
int func_gen_locals( struct function *f );
int func_gen_proto( struct function *f, char *buf, int len );

int func_foreach_addr( struct function *f, BAPI_CALLBACK fn, void *arg );
int func_foreach_code( struct function *f, BAPI_CALLBACK fn, void *arg );
 /*
 MakeFunction();
 SetFunctionComment();
 GetFunctionComment();
 GetFunctionPrototype();
    A type of comment
 SetFunctionPrototype();
 MakeInlineFunction( addr, name );
 ApplyInlineFunction( name );
    consider these to be 'structs' for code...*/


/* Private Parts ;)  */
#ifndef INCLUDED_FROM_BASTARD_H

#endif

==> bastard-0.17-pre.tgz: bastard_src-0.17/include/api/api_func.h <==
/*  B A S T A R D    A P I  :  */
/*  */

#include <bdb.h>  /* main DB structure definitions */

/* Public Parts */
/*  func_new: 
 *    Return Value:   
 *     Arguments:       */
int func_new( long rva, char * name, int size, int flags );
/*  func_get_name: 
 *    Return Value:   
 *     Arguments:       */
int func_get_name( long rva, char *buf );
/*  func_get_start: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
unsigned long func_get_start( long rva );
/*  func_get_end: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
unsigned long func_get_end( long rva );
/*  func_get_by_name: 
 *    Return Value:   
 *     Arguments:       */
unsigned long func_get_by_name( char *name );
/*  func_set_name: 
 *    Return Value:   
 *     Arguments:       */
int func_set_name( long rva, char *name );
/*  func_set_size: 
 *    Return Value:   
 *     Arguments:       */
/* DANGER: This is inaccurate until 0- and 1-byte functions have been fixed */
int func_set_size( long rva, int size );
int func_gen_args( struct function *f );
int func_gen_effect( struct function *f );
int func_gen_locals( struct function *f );
int func_gen_proto( struct function *f, char *buf, int len );

int func_foreach( BAPI_CALLBACK fn, void *arg);
int func_foreach_addr( struct function *f, BAPI_CALLBACK fn, void *arg );
int func_foreach_code( struct function *f, BAPI_CALLBACK fn, void *arg );
 /*
 MakeFunction();
 SetFunctionComment();
 GetFunctionComment();
 GetFunctionPrototype();
    A type of comment
 SetFunctionPrototype();
 MakeInlineFunction( addr, name );
 ApplyInlineFunction( name );
    consider these to be 'structs' for code...*/


/* Private Parts ;)  */
#ifndef INCLUDED_FROM_BASTARD_H

#endif
